@@ -86,13 +86,15 @@ sub fileHandle
         return $self->{_filehandle}
             if (    defined $self->{_filehandle}
                 and $self->{_filehandle}->isa("IO::File")
+                and defined fileno($self->{_filehandle})
                 and defined $today
                 and strftime(TODAY_FORMAT, localtime(time)) eq $today);
 
         # we need a new file.  Close our filehandle if it exists
         $self->{_filehandle}->close()
-            if (defined $self->{_filehandle}
-                and $self->{_filehandle}->isa("IO::File"));
+            if (    defined $self->{_filehandle}
+                and $self->{_filehandle}->isa("IO::File")
+                and defined fileno($self->{_filehandle}));
 
         # generate file name
         my $filename =
@@ -115,14 +117,6 @@ sub fileHandle
 
 }          # fileHandle();
 
-=head1 SEE ALSO
-
-L<perl>, L<Log::Fine>, L<Log::Fine::Handle::File>
-
-=head1 AUTHOR
-
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -162,7 +156,15 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: d20338cd73faa205858eea313ee3ef7356f906eb $
+  $Id: 302f48d6b422d61fee43ff8e185c4693dbec0bc3 $
+
+=head1 AUTHOR
+
+Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+
+=head1 SEE ALSO
+
+L<perl>, L<Log::Fine>, L<Log::Fine::Handle::File>
 
 =head1 COPYRIGHT & LICENSE
 
